$cms-primary: #0bf;
$cms-gray: #ddd;
$dark-fg: lightgray;

$django-dark-bg: #121212;
$django-dark-select: #00363a;
$django-dark-color: #eee;
$django-fg: #333;
$white: #fff;

$font-size-base: 0.8125rem;
$nav-link-padding-y: 0.3rem;
$nav-pills-border-radius: 4px;
$component-active-bg: $cms-primary;
