.colM ul:not(.object-tools).nav {
    margin-top: 0;
    margin-bottom: 20px;
}

ul.nav {
    &:not(:has(> li:nth-child(2))) {
        // Hide single tab
        display: none;
    }
    .nav-item {
        margin-inline-end: 1rem;
    }
    // margin-bottom: 0;
    .nav-link {
        position: relative;
        text-decoration: none;

        span.indicator {
            display: none;
            border-radius: 50%;

            &.error {
                background-color: var(--bs-danger);
            }

            &.attributes {
                background-color: var(--bs-info);
                display: block;
            }

            padding: 0.5rem;
            border: 1px solid var(--dca-white, var(--body-bg, $white));
            transform: translate(-50%, -50%);
            inset-block-start: 0;
            inset-inline-start: 100%;
            position: absolute;
        }

        &.error > span.indicator {
            display: block;
        }
    }
}

ul.nav.nav-pills .nav-link:not(.active) {
    border-style: solid;
    border-width: 1px;
}

body:not(.djangocms-admin-style) ul.djangocms-frontend.nav-tabs + div.tab-content .tab-pane {
    border-left-style: solid;
    border-bottom-style: solid;
    border-right-style: solid;
    border-left-color: var(--hairline-color);
    border-bottom-color: var(--hairline-color);
    border-right-color: var(--hairline-color);
    border-width: 1px;

    fieldset:last-child {
        margin-bottom: 0;
    }
}

div.tab-pk {
    align-self: center;
    color: var(--dca-gray-darker, var(--body-fg, $django-fg));
    font-size: 80%;
    margin-inline-start: auto;
}

.djangocms-admin-style .colM ul.nav:not(.object-tools):not(.messagelist) {
    margin-top: 0;
    li.nav-item {
        border-top: none;
    }
}
